@@ -11,7 +11,7 @@ import subprocess
 from tabulate import tabulate
 from pathlib import Path
 from subprocess import Popen, PIPE
-from _version import __version__
+from cam.version import __version__
 import datetime
 HOME = str(Path.home())
 CONFIG_FILE = "{0}/.cam.conf".format(HOME)
@@ -117,7 +117,7 @@ class CAM(object):
         <br>`cam worker "some start condition" prefix suffix` will add prefix and suffix to the command.
         """
         log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
-        log_info("Worker started. Listening to {0} ...".format(self._conf['server']))
+        log_info("Worker {0} started.".format(get_host()))
         worker_start_time = get_time()
         self.worker_id = get_host()
         os.system("tmux rename-window cam%d"%os.getpid())
@@ -135,8 +135,8 @@ class CAM(object):
                 self.running_job_id, ptime, cmd, status = json.loads(row_str.decode("utf-8"))
                 cmd = "".join([cmdprefix, cmd, cmdsuffix])
                 self._redis.lpush("running", json.dumps([self.running_job_id, get_time(), cmd, get_host()]))
-                log_info("Running task: %d"%self.running_job_id)
-                log_info("Running command: ", cmd)
+                log_info("{0} Running task: {1}".format(self.worker_id, self.running_job_id))
+                log_info("{0} Running command: {1}".format(self.worker_id, cmd), )
                 self.p = Popen(cmd, shell=True)
                 worker_start_time = get_time()
                 self._redis.hset("workers", self.worker_id, json.dumps([worker_start_time, "Running %d"%self.running_job_id, cond, cmdprefix, cmdsuffix]))
@@ -155,7 +155,7 @@ class CAM(object):
                         break
                     except:
                         pass
-                log_info("Finished command: ", cmd)
+                log_info("{0} Finished command: {1}".format(self.worker_id, cmd))
                 self._remove_by_tid("running", self.running_job_id)
             time.sleep(5)
             
